'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

exports.bitbucketRequest = bitbucketRequest;
exports.getPullRequests = getPullRequests;
exports.createPullRequest = createPullRequest;
exports.getRepository = getRepository;
exports.getRepositoryStatuses = getRepositoryStatuses;
exports.getRepositoryDefaultReviewers = getRepositoryDefaultReviewers;
exports.addPullRequestComment = addPullRequestComment;

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _config = require('./config');

var _gitCli = require('./git-cli');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const GIT_REPO_NAME = (0, _gitCli.getRemoteRepositoryName)();
const GIT_REPO_ORIGIN_USERNAME = (0, _gitCli.getRemoteUsername)();
const BITBUCKET_API_BASEURL = `https://bitbucket.org/!api/2.0/repositories/${GIT_REPO_ORIGIN_USERNAME}/${GIT_REPO_NAME}`;

function handleResponse(response) {
  // console.log('data - ', response.data)
  return response.data;
}

function handleError(error) {
  // console.log('error - ', JSON.stringify(error.response.data.error))
  // console.log('error - ', error)
  return error.response.data.error;
}

function bitbucketRequest(url, params = {}, method) {
  const BITBUCKET_TOKEN = (0, _config.getBitbucketToken)();
  return (0, _axios2.default)({
    url,
    method: method || 'get',
    data: params,
    headers: {
      'Content-Type': 'application/json',
      Authorization: `Basic ${BITBUCKET_TOKEN}`
    }
  }).then(handleResponse).catch(e => _promise2.default.reject(handleError(e)));
}

function buildAPIUrl(path) {
  return `${BITBUCKET_API_BASEURL}/${path}`;
}

// TODO: recurse to get all pages of pull requests
function getPullRequests() {
  return bitbucketRequest(buildAPIUrl('pullrequests')).then(data => data.values);
}

function createPullRequest(data) {
  return bitbucketRequest(buildAPIUrl('pullrequests'), data, 'POST');
}

function getRepository() {
  return bitbucketRequest(BITBUCKET_API_BASEURL);
}

function getRepositoryStatuses(pullrequestId) {
  return bitbucketRequest(buildAPIUrl(`pullrequests/${pullrequestId}/statuses`)).then(data => data.values);
}

// TODO: recurse to get all pages of pull requests
function getRepositoryDefaultReviewers() {
  return bitbucketRequest(buildAPIUrl('default-reviewers')).then(data => data && data.values ? data.values : []).catch(e => {
    console.log(_chalk2.default.yellow("You don't have access to default reviewers."));
    return [];
  });
}

// 1.0 API no longer available. No support for 2.0
const BITBUCKET_API_BASEURL_VERSION1 = `https://bitbucket.org/!api/1.0/repositories/${GIT_REPO_ORIGIN_USERNAME}/${GIT_REPO_NAME}`;
function addPullRequestComment(prId, comment) {
  return bitbucketRequest(`${BITBUCKET_API_BASEURL_VERSION1}/pullrequests/${prId}/comments`, comment, 'post');
}
//# sourceMappingURL=bitbucket.js.map