'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.runCommit = exports.promptCommit = undefined;

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

let promptCommit = exports.promptCommit = (() => {
  var _ref = (0, _asyncToGenerator3.default)(function* ({ message, smart } = {}) {
    const currentBranch = (0, _gitCli.getBranch)();
    const initialMessage = typeof smart === 'string' ? smart : message;
    let smartMessage;

    try {
      const { addmessage } = yield _inquirer2.default.prompt({
        type: 'input',
        name: 'addmessage',
        message: `${currentBranch}:`,
        validate: function (val) {
          return !!val;
        },
        when: function () {
          return !initialMessage;
        }
      });

      const commitMessage = initialMessage || addmessage;

      if ((0, _config.requireSmartCommits)() || smart) {
        const issueName = getIssueFromBranch(currentBranch);

        const { issue } = yield _inquirer2.default.prompt({
          type: 'input',
          name: 'issue',
          message: 'Issue:',
          default: issueName,
          validate: function (val) {
            return !!val;
          },
          when: function () {
            return true;
          }
        });

        const { time } = yield _inquirer2.default.prompt({
          type: 'input',
          name: 'time',
          message: 'How much time have you spent? w/d/h/m/(s)kip',
          default: 'skip',
          validate: function (val) {
            return !!val;
          },
          when: function () {
            return true;
          }
        });

        if (time.includes('w') || time.includes('d') || time.includes('h') || time.includes('m')) {
          smartMessage = `${issue} #time ${time}`;
        } else {
          console.log(_chalk2.default.magenta('No time was tracked'));
        }
      }

      const completeMessage = `${commitMessage}${smartMessage ? `\n\n${smartMessage}` : ''}`;
      execCommit(completeMessage);

      const randomNum = Math.ceil(Math.random() * 10);
      if ([3, 7].includes(randomNum)) {
        console.log(_chalk2.default.yellow('Nailed it!'));
      }
      if ([2, 5].includes(randomNum)) {
        console.log(_chalk2.default.cyan('Mmmm, the people are gonna like that!'));
      }

      return { success: true };
    } catch (e) {
      throw e;
    }
  });

  return function promptCommit() {
    return _ref.apply(this, arguments);
  };
})();

let runCommit = exports.runCommit = (() => {
  var _ref2 = (0, _asyncToGenerator3.default)(function* (args) {
    try {
      return yield promptCommit(args);
    } catch (e) {
      if (e && e.message) {
        console.log(_chalk2.default.magenta(e.message));
        if (e.message.startsWith('Command failed')) {
          console.log(_chalk2.default.yellow('Did you add your changes?'));
        }
      } else {
        console.log(_chalk2.default.yellow('There was an unknown error.'));
      }
      return '';
    }
  });

  return function runCommit(_x) {
    return _ref2.apply(this, arguments);
  };
})();

exports.getIssueFromBranch = getIssueFromBranch;
exports.formatMessage = formatMessage;
exports.execCommit = execCommit;

var _inquirer = require('inquirer');

var _inquirer2 = _interopRequireDefault(_inquirer);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _config = require('./config');

var _gitCli = require('./git-cli');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getIssueFromBranch(branch) {
  const [type, issue] = branch.split('/');
  return issue;
}

function formatMessage({ message, branch }) {
  return `${branch}: ${message}`;
}

function execCommit(message) {
  const branch = (0, _gitCli.getBranch)();
  const commitMessage = formatMessage({ message, branch });
  const result = (0, _gitCli.createCommit)(commitMessage);
  console.log(result);
  return result;
}
//# sourceMappingURL=commit.js.map